import socket
import json
import os

if "AUTOPROFILE_AGENT_SOCKET" in os.environ:
    AGENT_SOCKET = os.environ["AUTOPROFILE_AGENT_SOCKET"]
else:
    AGENT_SOCKET = "/autoprofile-agent.sock"

sock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
try:
    sock.connect(AGENT_SOCKET)
except ConnectionRefusedError:
    raise Exception("Could not connect to agent")    


def get_parameters() -> dict[str]:
    sock.sendall(b"get_parameters\n")
    
    try:
        length = int.from_bytes(sock.recv(4), 'big')
        
        data = b''
        while len(data) < length:
            data += sock.recv(length - len(data))
    except Exception as e:
        raise Exception("Failed to communicate with agent", e)
    
    try:
        return json.loads(data)
    except Exception as e:
        raise Exception("Failed to parse data", e)
    
def profiling_start():
    try:
        sock.sendall(b"start\n")
    except Exception as e:
        raise Exception("Failed to communicate with agent", e)

def profiling_stop():
    try:
        sock.sendall(b"stop\n")
    except Exception as e:
        raise Exception("Failed to communicate with agent", e)
